==> keybase-5.1.1.tar.gz: client-5.1.1/shared/chat/conversation/messages/cards/hello-bot.tsx <==
import * as React from 'react'
import * as Kb from '../../../../common-adapters'
import * as Styles from '../../../../styles'

type Props = {}

const HelloBot = (_: Props) => (
  <Kb.Box2 direction="horizontal" style={styles.container} alignItems="flex-start">
    <Kb.Icon type="icon-fancy-hellobot-hi-96" style={styles.image} />
    <Kb.Box2 direction="vertical" gap="xtiny" fullHeight={true} style={styles.textContainer}>
      <Kb.Text type="BodySmallSemibold" style={styles.header} negative={true}>
        Hi, I'm Hello Bot. You can play puzzles with me or ask for help.
      </Kb.Text>
      <Kb.Text type="BodySmallSemibold" style={styles.header} negative={true}>
        Everyday is an adventure.
      </Kb.Text>
    </Kb.Box2>
  </Kb.Box2>
)

const styles = Styles.styleSheetCreate(
  () =>
    ({
      container: Styles.platformStyles({
        common: {
          backgroundColor: Styles.globalColors.orange,
          borderRadius: Styles.borderRadius,
        },
        isElectron: {
          height: 100,
          marginTop: Styles.globalMargins.xsmall,
          maxWidth: 400,
        },
        isMobile: {
          marginLeft: Styles.globalMargins.small,
          marginRight: Styles.globalMargins.small,
          marginTop: Styles.globalMargins.small,
          width: 288,
        },
      }),
      header: {
        maxWidth: Styles.isMobile ? 126 : undefined,
      },
      icon: Styles.platformStyles({
        isElectron: {
          display: 'block',
          marginTop: 4,
        },
      }),
      image: {
        alignSelf: Styles.isMobile ? 'center' : undefined,
        marginTop: Styles.isMobile ? Styles.globalMargins.tiny : -Styles.globalMargins.xsmall,
        paddingLeft: Styles.globalMargins.medium,
      },
      link: {color: Styles.isMobile ? Styles.globalColors.blueLighter : undefined},
      textContainer: {padding: Styles.globalMargins.medium},
    } as const)
)

export default HelloBot

==> keybase-6.2.4.tar.gz: client-6.2.4/shared/chat/conversation/messages/cards/hello-bot.tsx <==
import * as Kb from '../../../../common-adapters'
import * as Styles from '../../../../styles'

type Props = {}

const HelloBot = (_: Props) => (
  <Kb.Box2 direction="horizontal" style={styles.container} alignItems="flex-start">
    <Kb.Icon type="icon-fancy-hellobot-hi-96" style={styles.image} />
    <Kb.Box2 direction="vertical" gap="xtiny" fullHeight={true} style={styles.textContainer}>
      <Kb.Text type="BodySmallSemibold" style={styles.header} negative={true}>
        Hi, I'm Hello Bot. You can play puzzles with me or ask for help.
      </Kb.Text>
      <Kb.Text type="BodySmallSemibold" style={styles.header} negative={true}>
        Everyday is an adventure.
      </Kb.Text>
    </Kb.Box2>
  </Kb.Box2>
)

const styles = Styles.styleSheetCreate(
  () =>
    ({
      container: Styles.platformStyles({
        common: {
          backgroundColor: Styles.globalColors.orange,
          borderRadius: Styles.borderRadius,
        },
        isElectron: {
          height: 100,
          marginTop: Styles.globalMargins.xsmall,
          maxWidth: 400,
        },
        isMobile: {
          marginLeft: Styles.globalMargins.small,
          marginRight: Styles.globalMargins.small,
          marginTop: Styles.globalMargins.small,
          width: 288,
        },
      }),
      header: {
        maxWidth: Styles.isMobile ? 126 : undefined,
      },
      icon: Styles.platformStyles({
        isElectron: {
          display: 'block',
          marginTop: 4,
        },
      }),
      image: Styles.platformStyles({
        common: {
          marginLeft: Styles.globalMargins.medium,
        },
        isElectron: {
          marginTop: -Styles.globalMargins.xsmall,
        },
        isMobile: {
          alignSelf: 'center',
          marginTop: Styles.globalMargins.tiny,
        },
      }),
      link: {color: Styles.isMobile ? Styles.globalColors.blueLighter : undefined},
      textContainer: {padding: Styles.globalMargins.medium},
    } as const)
)

export default HelloBot
